==> zio-aws-honeycode_3-5.17.104.11-sources.jar: zio/aws/honeycode/model/QueryTableRowsResponse.scala <==
package zio.aws.honeycode.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.honeycode.model.primitives.{
  WorkbookCursor,
  PaginationToken,
  ResourceId
}
import scala.jdk.CollectionConverters.*
final case class QueryTableRowsResponse(
    columnIds: Iterable[ResourceId],
    rows: Iterable[zio.aws.honeycode.model.TableRow],
    nextToken: Option[PaginationToken] = None,
    workbookCursor: WorkbookCursor
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse = {
    import QueryTableRowsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
      .builder()
      .columnIds(columnIds.map { item =>
        ResourceId.unwrap(item): java.lang.String
      }.asJavaCollection)
      .rows(rows.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .workbookCursor(WorkbookCursor.unwrap(workbookCursor): java.lang.Long)
      .build()
  }
  def asReadOnly: zio.aws.honeycode.model.QueryTableRowsResponse.ReadOnly =
    zio.aws.honeycode.model.QueryTableRowsResponse.wrap(buildAwsValue())
}
object QueryTableRowsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.honeycode.model.QueryTableRowsResponse =
      zio.aws.honeycode.model.QueryTableRowsResponse(
        columnIds,
        rows.map { item =>
          item.asEditable
        },
        nextToken.map(value => value),
        workbookCursor
      )
    def columnIds: List[ResourceId]
    def rows: List[zio.aws.honeycode.model.TableRow.ReadOnly]
    def nextToken: Option[PaginationToken]
    def workbookCursor: WorkbookCursor
    def getColumnIds: ZIO[Any, Nothing, List[ResourceId]] =
      ZIO.succeed(columnIds)
    def getRows
        : ZIO[Any, Nothing, List[zio.aws.honeycode.model.TableRow.ReadOnly]] =
      ZIO.succeed(rows)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getWorkbookCursor: ZIO[Any, Nothing, WorkbookCursor] =
      ZIO.succeed(workbookCursor)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
  ) extends zio.aws.honeycode.model.QueryTableRowsResponse.ReadOnly {
    override val columnIds: List[ResourceId] = impl
      .columnIds()
      .asScala
      .map { item =>
        zio.aws.honeycode.model.primitives.ResourceId(item)
      }
      .toList
    override val rows: List[zio.aws.honeycode.model.TableRow.ReadOnly] = impl
      .rows()
      .asScala
      .map { item =>
        zio.aws.honeycode.model.TableRow.wrap(item)
      }
      .toList
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.honeycode.model.primitives.PaginationToken(value))
    override val workbookCursor: WorkbookCursor =
      zio.aws.honeycode.model.primitives.WorkbookCursor(impl.workbookCursor())
  }
  def wrap(
      impl: software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
  ): zio.aws.honeycode.model.QueryTableRowsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-honeycode_3-5.19.8.4-sources.jar: zio/aws/honeycode/model/QueryTableRowsResponse.scala <==
package zio.aws.honeycode.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.honeycode.model.primitives.{
  WorkbookCursor,
  PaginationToken,
  ResourceId
}
import scala.jdk.CollectionConverters.*
final case class QueryTableRowsResponse(
    columnIds: Iterable[ResourceId],
    rows: Iterable[zio.aws.honeycode.model.TableRow],
    nextToken: Optional[PaginationToken] = Optional.Absent,
    workbookCursor: WorkbookCursor
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse = {
    import QueryTableRowsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
      .builder()
      .columnIds(columnIds.map { item =>
        ResourceId.unwrap(item): java.lang.String
      }.asJavaCollection)
      .rows(rows.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .workbookCursor(WorkbookCursor.unwrap(workbookCursor): java.lang.Long)
      .build()
  }
  def asReadOnly: zio.aws.honeycode.model.QueryTableRowsResponse.ReadOnly =
    zio.aws.honeycode.model.QueryTableRowsResponse.wrap(buildAwsValue())
}
object QueryTableRowsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.honeycode.model.QueryTableRowsResponse =
      zio.aws.honeycode.model.QueryTableRowsResponse(
        columnIds,
        rows.map { item =>
          item.asEditable
        },
        nextToken.map(value => value),
        workbookCursor
      )
    def columnIds: List[ResourceId]
    def rows: List[zio.aws.honeycode.model.TableRow.ReadOnly]
    def nextToken: Optional[PaginationToken]
    def workbookCursor: WorkbookCursor
    def getColumnIds: ZIO[Any, Nothing, List[ResourceId]] =
      ZIO.succeed(columnIds)
    def getRows
        : ZIO[Any, Nothing, List[zio.aws.honeycode.model.TableRow.ReadOnly]] =
      ZIO.succeed(rows)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getWorkbookCursor: ZIO[Any, Nothing, WorkbookCursor] =
      ZIO.succeed(workbookCursor)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
  ) extends zio.aws.honeycode.model.QueryTableRowsResponse.ReadOnly {
    override val columnIds: List[ResourceId] = impl
      .columnIds()
      .asScala
      .map { item =>
        zio.aws.honeycode.model.primitives.ResourceId(item)
      }
      .toList
    override val rows: List[zio.aws.honeycode.model.TableRow.ReadOnly] = impl
      .rows()
      .asScala
      .map { item =>
        zio.aws.honeycode.model.TableRow.wrap(item)
      }
      .toList
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.honeycode.model.primitives.PaginationToken(value))
    override val workbookCursor: WorkbookCursor =
      zio.aws.honeycode.model.primitives.WorkbookCursor(impl.workbookCursor())
  }
  def wrap(
      impl: software.amazon.awssdk.services.honeycode.model.QueryTableRowsResponse
  ): zio.aws.honeycode.model.QueryTableRowsResponse.ReadOnly = new Wrapper(impl)
}
